@@ -201,7 +201,7 @@ class WebDriver(webdriver.Remote):
                 duration = duration
                 action.long_press(x=x, y=y, duration=duration).release()
             else:
-                action.press(x=x, y=y).release()
+                action.tap(x=x, y=y).release()
             action.perform()
         else:
             ma = MultiAction(self)
@@ -329,14 +329,23 @@ class WebDriver(webdriver.Remote):
         self.execute(Command.RESET)
         return self
 
-    def hide_keyboard(self, key_name=None):
-        """Hides the software keyboard on the device, using the specified key to
-        press. If no key name is given, the keyboard is closed by moving focus
-        from the text field. iOS only.
+    def hide_keyboard(self, key_name=None, key=None, strategy=None):
+        """Hides the software keyboard on the device. In iOS, use `key_name` to press
+        a particular key, or `strategy`. In Android, no parameters are used.
+
+        :Args:
+         - key_name - key to press
+         - strategy - strategy for closing the keyboard (e.g., `tapOutside`)
         """
         data = {}
         if key_name is not None:
             data['keyName'] = key_name
+        elif key is not None:
+            data['key'] = key
+        else:
+            # defaults to `tapOutside` strategy
+            strategy = 'tapOutside'
+        data['strategy'] = strategy
         self.execute(Command.HIDE_KEYBOARD, data)
         return self
 
@@ -421,6 +430,18 @@ class WebDriver(webdriver.Remote):
         }
         return self.execute(Command.PULL_FILE, data)['value']
 
+    def pull_folder(self, path):
+        """Retrieves a folder at `path`. Returns the folder's contents zipped
+        and encoded as Base64.
+
+        :Args:
+         - path - the path to the folder on the device
+        """
+        data = {
+            'path': path,
+        }
+        return self.execute(Command.PULL_FOLDER, data)['value']
+
     def push_file(self, path, base64data):
         """Puts the data, encoded as Base64, in the file specified as `path`.
 
@@ -574,6 +595,8 @@ class WebDriver(webdriver.Remote):
             ('POST', '/session/$sessionId/appium/element/$elementId/value')
         self.command_executor._commands[Command.PULL_FILE] = \
             ('POST', '/session/$sessionId/appium/device/pull_file')
+        self.command_executor._commands[Command.PULL_FOLDER] = \
+            ('POST', '/session/$sessionId/appium/device/pull_folder')
         self.command_executor._commands[Command.PUSH_FILE] = \
             ('POST', '/session/$sessionId/appium/device/push_file')
         self.command_executor._commands[Command.COMPLEX_FIND] = \
